@@ -32,7 +32,7 @@ import (
 
 const (
 	OldestHandledVersion = 10
-	CurrentVersion       = 22
+	CurrentVersion       = 23
 	MaxRescanIntervalS   = 365 * 24 * 60 * 60
 )
 
@@ -323,6 +323,9 @@ func (cfg *Configuration) clean() error {
 	if cfg.Version == 21 {
 		convertV21V22(cfg)
 	}
+	if cfg.Version == 22 {
+		convertV22V23(cfg)
+	}
 
 	// Build a list of available devices
 	existingDevices := make(map[protocol.DeviceID]bool)
@@ -372,6 +375,33 @@ func (cfg *Configuration) clean() error {
 	return nil
 }
 
+func convertV22V23(cfg *Configuration) {
+	permBits := fs.FileMode(0777)
+	if runtime.GOOS == "windows" {
+		// Windows has no umask so we must chose a safer set of bits to
+		// begin with.
+		permBits = 0700
+	}
+	for i := range cfg.Folders {
+		fs := cfg.Folders[i].Filesystem()
+		// Invalid config posted, or tests.
+		if fs == nil {
+			continue
+		}
+		if stat, err := fs.Stat(".stfolder"); err == nil && !stat.IsDir() {
+			err = fs.Remove(".stfolder")
+			if err == nil {
+				err = fs.Mkdir(".stfolder", permBits)
+			}
+			if err != nil {
+				l.Fatalln("failed to upgrade folder marker:", err)
+			}
+		}
+	}
+
+	cfg.Version = 23
+}
+
 func convertV21V22(cfg *Configuration) {
 	for i := range cfg.Folders {
 		cfg.Folders[i].FilesystemType = fs.FilesystemTypeBasic
